from __future__ import annotations

from .Any2AnyMultiChoice import *
from .Any2AnyRetrieval import *
from .ImageClassification import *
from .ImageClustering import *
from .ImageMultilabelClassification import *
from .ImageTextPairClassification import *
from .VisualSTS import *
from .ZeroShotClassification import *
