from __future__ import annotations

from .ita.EmitClassification import *
from .kor.KorHateSpeechMLClassification import *
from .mlt.MalteseNewsClassification import *
from .multilingual.MultiEURLEXMultilabelClassification import *
from .por.BrazilianToxicTweetsClassification import *
from .rus.CEDRClassification import *
from .rus.ru_toixic_multilabelclassification_okmlcup import *
from .rus.SensitiveTopicsClassification import *
